@@ -225,7 +225,6 @@ C *** *** *** *** *** *** *** *** *** *** *** *** ***
       DIMENSION Y(N),ATOL(*),RTOL(*),WORK(LWORK),IWORK(LIWORK)
       DIMENSION RPAR(*),IPAR(*),VSTI(N)
       DOUBLE PRECISION KAPPA, GAMMA,SIGMA,SIGMATOT
-      character(len=150) msg
       LOGICAL ARRET
       EXTERNAL FCN
       EXTERNAL SOLOUT
@@ -250,9 +249,7 @@ C -------- NMAX , THE MAXIMAL NUMBER OF STEPS -----
          NMAX=IWORK(1)
          IF(NMAX.LE.0)THEN
             IF (IPRINT.GT.0) THEN
-              WRITE(MSG,*)
-     &          ' WRONG INPUT IWORK(1)=',IWORK(1)
-              CALL RPRINT(MSG)
+        CALL Rprinti1('wrong input iwork(1) = ',IWORK(1))
             END IF
             ARRET=.TRUE.
          END IF
@@ -264,9 +261,7 @@ C -------- METH   COEFFICIENTS OF THE METHOD
          METH=IWORK(2)
          IF(METH.LE.0.OR.METH.GE.4)THEN
             IF (IPRINT.GT.0) THEN
-               WRITE(MSG,*)
-     &          ' CURIOUS INPUT IWORK(2)=',IWORK(2)
-               CALL RPRINT(MSG)
+        CALL Rprinti1('Curious input iwork(2) = ',IWORK(2))
             END IF
             ARRET=.TRUE.
          END IF
@@ -279,17 +274,13 @@ C -------- NRDENS   NUMBER OF DENSE OUTPUT COMPONENTS
       NRDENS=IWORK(5)
       IF(NRDENS.LT.0.OR.NRDENS.GT.N)THEN
          IF (IPRINT.GT.0) THEN
-            WRITE(MSG,*)
-     &           ' CURIOUS INPUT IWORK(5)=',IWORK(5)
-            CALL  RPRINT(MSG)
+        CALL Rprinti1('Curious input iwork(5) = ',IWORK(5))
          END IF
          ARRET=.TRUE.
       ELSE
             IF(NRDENS.GT.0.AND.IOUT.LT.2)THEN
                IF (IPRINT.GT.0)  THEN
-                  WRITE(MSG,*)
-     &      ' WARNING: PUT IOUT=2 FOR DENSE OUTPUT '
-                 CALL RPRINT(MSG)
+        CALL Rprint('Warning: put IOUT=2 for dense output ')
                END IF
             END IF
             IF (NRDENS.EQ.N) THEN
@@ -309,9 +300,8 @@ C -------- UROUND   SMALLEST NUMBER SATISFYING 1.D0+UROUND>1.D0
          UROUND=WORK(1)
          IF(UROUND.LE.1.D-35.OR.UROUND.GE.1.D0)THEN
             IF (IPRINT.GT.0) THEN
-              WRITE(MSG,*)
-     &        ' WHICH MACHINE DO YOU HAVE? YOUR UROUND WAS:',WORK(1)
-             CALL RPRINT(MSG)
+        CALL Rprintd1(
+     &        ' Which machine do you have? Your uround was: ',WORK(1))
             END IF
             ARRET=.TRUE.
          END IF
@@ -323,9 +313,8 @@ C -------  SAFETY FACTOR -------------
          SAFE=WORK(2)
          IF(SAFE.GE.1.D0.OR.SAFE.LE.1.D-4)THEN
             IF (IPRINT.GT.0) THEN
-               WRITE(MSG,*)
-     &          ' CURIOUS INPUT FOR SAFETY FACTOR WORK(2)=',WORK(2)
-              CALL RPRINT(MSG)
+        CALL Rprintd1(
+     &          'Curious input for safety factor work(2) = ',WORK(2))
             END IF
             ARRET=.TRUE.
          END IF
@@ -351,9 +340,7 @@ C --------- BETA FOR STEP CONTROL STABILIZATION -----------
             BETA=WORK(5)
             IF(BETA.GT.0.2D0)THEN
                IF (IPRINT.GT.0) THEN
-                  WRITE(MSG,*)
-     &          ' CURIOUS INPUT FOR BETA: WORK(5)=',WORK(5)
-                 CALL RPRINT(MSG)
+        CALL Rprintd1('Curious input for beta: work(5) = ',WORK(5))
                END IF
             ARRET=.TRUE.
          END IF
@@ -393,9 +380,7 @@ C ------ TOTAL STORAGE REQUIREMENT -----------
       ISTORE=IEYSTIS+7*NRDENS-1
       IF(ISTORE.GT.LWORK)THEN
         IF (IPRINT.GT.0)  THEN
-          WRITE(MSG,*)
-     &   ' INSUFFICIENT STORAGE FOR WORK, MIN. LWORK=',ISTORE
-          CALL RPRINT(MSG)
+        CALL Rprinti1('Insufficient storage for work, min. = ',ISTORE)
         END IF
         ARRET=.TRUE.
       END IF
@@ -403,9 +388,7 @@ C ------ TOTAL STORAGE REQUIREMENT -----------
       ISTORE=ICOMP+NRDENS-1
       IF(ISTORE.GT.LIWORK)THEN
         IF (IPRINT.GT.0) THEN
-          WRITE(MSG,*)
-     &   ' INSUFFICIENT STORAGE FOR IWORK, MIN. LIWORK=',ISTORE
-         CALL RPRINT(MSG)
+        CALL Rprinti1('Insufficient storage for iwork, min. = ',ISTORE)
         END IF
         ARRET=.TRUE.
       END IF
@@ -468,7 +451,6 @@ C ----------------------------------------------------------
       DOUBLE PRECISION ETAVE(N)
       DOUBLE PRECISION  D1,D3,D4,D5,D6,D7
       LOGICAL REJECT,LAST
-      character(len=150) msg
       EXTERNAL FCN
       LOGICAL HERMITE
       COMMON /CONTCKV/XOLD,HOUT,HERMITE
@@ -575,18 +557,23 @@ c  two norm of etave
          DO I=1,N
           ENORMVE = MAX(ENORMVE,ABS(ETAVE(I)))
          END DO
-         IF (ENORMVE .GT. 0.0d0) THEN
+
+         IF ( ENORMVE .GT. 0.0d0 .AND.
+     +         (.NOT. (.NOT. ENORMVE .GT. 0.0d0))
+     +     .AND.  (.NOT. ENORMVE .GT. 1d300)  ) THEN
            DO I=1,N
             ETAVE(I) = ETAVE(I)/ENORMVE
            END DO
            IFLAGST = 0
-         ELSE
+         ELSE IF  (.NOT. (.NOT. ENORMVE .GT. 0.0d0 )) THEN
 cF we try with a bigger stepsize
            HST = 2*HST
          ENDIF
 cF errors in function evaluation we reduce the stepsize
- 333     IF (IERR .NE.0) HST = HST/10.0d0
-         NFCN=NFCN+6
+  333    IF (IERR .NE.0  .OR. .NOT. (ENORMVE .GT. 0.0d0)
+     +                .OR. ENORMVE .GT. 1d300 )
+     +             HST = HST/10.0d0
+          NFCN=NFCN+6
        END DO
 c ERROR ESTIMATION FOR THE COMPUTATION OF THE INITIAL STEPSIZE
 
@@ -613,27 +600,22 @@ C --- ERROR ESTIMATION
           END DO
         END IF
         ERR=SQRT(ERR/N)
-        if (iprint .gt. 0 ) then
-           write(msg,477) err
-           call rprint(msg)
-        end if
       ENDIF
 
 
        HMAX=ABS(HMAX)
        IORD=5
-       H=HINITCKSTIFF(N,X,Y,XEND,POSNEG,K1,K2,Y1,IORD,
+
+       IF (H.EQ.0.D0) H=HINITCKSTIFF(N,X,Y,XEND,POSNEG,K1,K2,Y1,IORD,
      &                HMAX,HST,ERR,EXPO1,ATOL,RTOL,ITOL,RPAR,IPAR)
 
 
+      if (iprint .gt. 0 ) then
+        CALL Rprintd1('Initial step h = ', H)
+        end if
 cF end computation of eta for stiffness detection
 
-c       WRITE(6,*) 'ETAVE', (ETAVE(I),I=1,N)
-c       WRITE(6,*) 'Y1', (Y1(I),I=1,N)
-c       WRITE(6,*) 'YSTI', (YSTI(I),I=1,N)
-c       WRITE(6,*) 'HST', HST, 'H', H
-c       READ(*,*) ia
-CF
+
 CF normalization of etave using the input tolerances
 C
        SCAL_ETA = 1d-12
@@ -683,53 +665,54 @@ C removed ierr
        IERR = 0
        CALL FCN(N,X,YS,K1S,RPAR,IPAR)
        NFCN=NFCN+1
-       IF (IERR .NE. 0 ) THEN
-          write(msg,*) 'Stiffness detection based on conditioning
-     * cannot start, we do not use it'
-          CALL RPRINT(MSG)
+       IF (IERR .NE. 0  .OR.
+     *             (.NOT. ENORMVE .GT. 0.0d0)  ) THEN
+        CALL Rprint
+     *   ('Stiffness detection based on conditioning cannot be used')
           NSTIFFCOND = 0
-       END IF
-
 
+       ELSE
 cf  computation of the relative difference y-ys
-       ERRZ = 0.0d0
-       IF (ITOL.EQ.0) THEN
-        DO I=1,N
+        ERRZ = 0.0d0
+        IF (ITOL.EQ.0) THEN
+         DO I=1,N
           SK = ATOLI*SCAL_ATOL+RTOLI*ABS(Y(I))
           ERRZ = ERRZ + (ABS(Y(I)-YS(I))/SK)**2.0d0
-        END DO
-       ELSE
-        DO I=1,N
+         END DO
+        ELSE
+         DO I=1,N
           SK=ATOL(I)*SCAL_ATOL+RTOL(I)*(ABS(Y(I)))
           ERRZ = ERRZ + (abs(Y(I)-YS(I))/SK)**2.0d0
-        END DO
-       END IF
-       ERRZ = SQRT(ERRZ/N)
+         END DO
+        END IF
+        ERRZ = SQRT(ERRZ/N)
 c       write(*,*) 'ERRZ ', ERRZ
 cf end of computation of the relative difference y-ys
 cf initialization of conditioning parameters
-       KAPPA   = ENORMVE
-       ENORMZ1 = ENORMVE
-       GAMMA   = 0d0
-       SIGMA   = 0d0
-       SIGMATOT = 0.0d0
-       XST = X
-       NRESTART = 0
-CF Parameter for tesing stiffness
-       NST   = 0
-       NEST  = 0
-       NNST  = 0
-       NNEST = 0
-       MAXnst = 15
-       MAXIaSti = 15
-       sigmamMAX = 50d0
-       sigmaMAX = 100d0
-       nwarn1 = 0
-       nwarn2 = 0
-       nwarn3 = 0
-       nwarn4 = 0
-
-      ELSE
+        KAPPA   = ENORMVE
+        ENORMZ1 = ENORMVE
+        GAMMA   = 0d0
+        SIGMA   = 0d0
+        SIGMATOT = 0.0d0
+        XST = X
+        NRESTART = 0
+CF Parameter for testing stiffness
+        NST   = 0
+        NEST  = 0
+        NNST  = 0
+        NNEST = 0
+        MAXnst = 20
+        MAXIaSti = 15
+        sigmamMAX = 50d0
+        sigmaMAX = 100d0
+        nwarn1 = 0
+        nwarn2 = 0
+        nwarn3 = 0
+        nwarn4 = 0
+      END IF
+cF end if id nstiffcond .gt. 0
+      END IF
+      IF (.NOT. NSTIFFCOND .GT. 0 ) THEN
 cF stiffness is not used
 C removed ierr
        IERR = 0
@@ -816,12 +799,12 @@ C removed ierr
      +  +a75*k5(i)+a76*k6(i))
  277   continue
 
-      IF (NSTIFFERR .GT. 0) THEN
+c      IF (NSTIFFERR .GT. 0) THEN
        do 704 i=1,n
         vsti(i)=h*(ad1*k1(i)+ad2*k2(i)+ad3*k3(i)+ad4*k4(i)
      +   +ad5*k5(i)+ad6*k6(i))
  704   continue
-      END IF
+c      END IF
 
       XPH=X+h
 C removed ierr
@@ -922,21 +905,17 @@ C ------- STIFFNESS DETECTION  based on approximation of eigenvalues
                STDEN=STDEN+(Y1(I)-YSTI(I))**2
  64         CONTINUE
             IF (STDEN.GT.0.D0) HLAMB=H*SQRT(STNUM/STDEN)
-            if (iprint .gt. 0) then
-              write(msg,188) hlamb,stden,stnum
-              call rprint(msg)
-            end if
- 188   format(1x,'the first est',3g22.10)
-            IF (HLAMB.GT.3.25D0) THEN
+
+ 188   format(1x,'The first est',i5,3g22.10)
+            IF (HLAMB.GT.3.25D0 .OR. .NOT.(HLAMB .GT. 0.0d0) ) THEN
                NONSTI=0
                IASTI=IASTI+1
                IF (IASTI.EQ.15) THEN
 C KARLINE: always print ...
 C                  IF (IPRINT.GT.0 .OR. NSTIFF .EQ. 1) THEN
-                    WRITE (msg,*)
-     &               'THE PROBLEM SEEMS TO BECOME STIFF AT X = ',X,
-     &               'USING THE STANDARD CHECK OF EIGENVALUES'
-                    CALL RPRINT(MSG)
+        CALL Rprintd1(
+     &               'The problem seems to become stiff at x = ',X)
+        CALL Rprint('using the standard check of eignevalues')
                     IF (NSTIFF .EQ. 2) GOTO 76
 C                  END IF
                END IF
@@ -955,21 +934,17 @@ cF approximation of the eiganvalues using ys
                STDEN=STDEN+(Y1(I)-YSTI(I)-Y1S(I)+YSTIS(I))**2
             END DO
             IF (STDEN.GT.0.D0) HLAMB=H*SQRT(STNUM/STDEN)
-            if (iprint .gt. 0) then
-               write(msg,189) hlamb,stden,stnum
-               CALL RPRINT(MSG)
-            end if
- 189       format(1x,'the first est using cond',3g22.10)
-            IF (HLAMB .GT. 2.8D0  .AND. HLAMB .LT. 4.2d0) THEN
+
+            IF ((HLAMB .GT. 2.8D0  .AND. HLAMB .LT. 4.2d0)
+     +               .OR. .NOT.(HLAMB .GT. 0.0d0) ) THEN
                NONSTIS=0
                IASTIS=IASTIS+1
                IF (IASTIS.EQ.15) THEN
 C Karline: always print
 C                  IF (IPRINT.GT.0 .OR. NSTIFFCOND.EQ. 1) THEN
-                    WRITE (MSG,*)
-     &               'THE PROBLEM SEEMS TO BECOME STIFF AT X = ',X,
-     &               'USING THE CHECK OF EIGENVALUES BASED ON YS'
-                    CALL RPRINT(MSG)
+        CALL Rprintd1(
+     &               'The problem seems to become stiff at x = ',X)
+        CALL Rprint('using the check of eigenvalues based on YS')
 C                  END IF
                   IF (NSTIFFCOND .EQ. 2) GOTO 76
                END IF
@@ -1021,11 +996,29 @@ C --- ERROR ESTIMATION
         errta=sqrt(errta/n)
         ERR = ERRy
 
-        if (iprint .gt. 0 ) then
-          write(msg,477) x, erry,errta
-          call rprint(msg)
-        end if
- 477   format(1x,'time ', g22.10, 'the two error estimates',2g22.10)
+        IF (NSTIFFERR .GT. 0) THEN
+          IF (ERRta .LT. 0.1d0*ERRY) THEN
+            Nerrta = Nerrta+1
+            NNerrta = 0
+          ELSE
+            NNerrta = NNerrta+1
+            IF (NNerrta .EQ. 6) THEN
+               Nerrta = 0
+            END IF
+          END IF
+          IF (Nerrta .EQ. 15) THEN
+        CALL Rprinti1(
+     &               'The problem seems to become stiff at x = ',X)
+        CALL Rprint('using stiffness detection based on error estimate')
+C            END IF
+            IF (NSTIFFERR .EQ. 2) THEN
+               IDID = -5
+               GOTO 760
+            END IF
+          END IF
+        END IF
+
+
 C --- ERROR ESTIMATION USING  YS
        IF (NSTIFFCOND .GT. 0 ) THEN
          ERRys=0.D0
@@ -1034,7 +1027,7 @@ C --- ERROR ESTIMATION USING  YS
            DO  I=1,N
             SK=ATOLI+RTOLI*max(abs(ys(i)),abs(y1s(i)))
             errys=errys+(YSTI(I)/sk)**2.0d0
-            SK=ATOLI*SCAL_ATOL+
+            SK=ATOLI*SCAL_ATOL +
      &           RTOLI*max(ABS(Y(I)-YS(I)),ABS(Y1(I)-Y1S(I)))
             ERRyys=ERRyys+(YSTIS(I)/SK)**2.0d0
            END DO
@@ -1042,7 +1035,7 @@ C --- ERROR ESTIMATION USING  YS
           DO  I=1,N
            SK=ATOL(I)+RTOL(I)*MAX(ABS(YS(I)),ABS(Y1S(I)))
            errys=errys+(YSTI(I)/sk)**2.0d0
-           SK=ATOL(I)*SCAL_ATOL+
+           SK=SCAL_ATOL+
      &         RTOL(I)*max(ABS(Y(I)-YS(I)),ABS(Y1(I)-Y1S(I)))
            ERRyys=ERRyys+(YSTIS(I)/SK)**2.0d0
           END DO
@@ -1055,12 +1048,6 @@ c the error is the maximum of the three error estimation
          ELSE
             ERR = ERRy
          END IF
-         if (iprint .gt. 0 ) then
-           write(msg, 478) x, errys, erryys, ERR
-           call rprint(msg)
- 478       format(1x,'time ', g12.5,
-     &    '  the 3 error estimates based on ys',3g22.10)
-         end if
 
        END IF
 cF end if 444
@@ -1075,50 +1062,16 @@ C --- LUND-STABILIZATION
 C --- WE REQUIRE  FAC1 <= HNEW/H <= FAC2
       FAC=MAX(FACC2,MIN(FACC1,FAC/SAFE))
       HNEW=H/FAC
-C KARLINE: toggled this off
-C      if (iprint .gt.0) then
-C         write(msg,433) h, hnew, fac, err
-C         call rprint(msg)
-C      end if
-C 433   format(1x,'new h',4g18.10)
 
       IF(ERR.LE.1.D0)THEN
 C --- STEP IS ACCEPTED
          FACOLD=MAX(ERR,1.0D-4)
          NACCPT=NACCPT+1
-C KARLINE: toggled this off
-C        if (iprint .gt. 0 ) then
-C          write(msg,488) naccpt,iasti
-C          call rprint(msg)
-C        end if
-C 488    format(1x,'naccpt ',i8,'iasti ',i8)
-c        This is the end of the second stiffness detector.
-        IF (NSTIFFERR .GT. 0) THEN
-          IF (ERRta .LT. 0.1d0*ERRY) THEN
-            Nerrta = Nerrta+1
-            NNerrta = 0
-          ELSE
-            NNerrta = NNerrta+1
-            IF (NNerrta .EQ. 6) THEN
-               Nerrta = 0
-            END IF
-          END IF
-          IF (Nerrta .EQ. 15) THEN
-C            IF (iprint .GT. 0) THEN
-C               write(msg,*) 'Stiffness  based on error estimation'
-C               call rprint(msg)
-               write(msg,*)
-     &               'THE PROBLEM SEEMS TO BECOME STIFF AT X = ',X,
-     &               'USING STIFFNESS DETECTION BASED ON ERROR',
-     &               'ESTIMATION'
-C            END IF
-            IF (NSTIFFERR .EQ. 2) THEN
-               IDID = -5
-               GOTO 760
-            END IF
-          END IF
-        END IF
 
+c        This is the end of the second stiffness detector.
+
+
+c        This is the end of the second stiffness detector
 c        This is the end of the second stiffness detector
 c set up continuous output
           IF (IOUT.GE.2 .AND. HERMITE) THEN
@@ -1136,7 +1089,7 @@ c set up continuous output
 c initialize the variables for the next step
           DO 44 I=1,N
             k1(i)=k2(i)
-  44       Y(I)=Y1(I)
+  44        Y(I)=Y1(I)
 
 c initialize the variables related to ys for the next step
       IF (NSTIFFCOND .GT. 0) THEN
@@ -1158,13 +1111,6 @@ c computation of kappa gamma and sigma
 
          sigma = (kappa/gamma)*(XPH-XST)
 
-         IF (IPRINT .GT. 0) THEN
-            write(msg,*) 'TIME',XPH, 'KAPPA',kappa/ENORMVE
-            CALL rprint(msg)
-            write(msg,*) 'gamma',(gamma/ENORMVE)/(XPH-XST),
-     &     'sigma',sigma,'sigmatot',sigmatot
-            CALL rprint(msg)
-         END IF
 
 cf relation between erry and errys
          IF (ERRY .LT. 0.1d0*ERRYYS) THEN
@@ -1172,7 +1118,7 @@ cf relation between erry and errys
             NEST = 0
          ELSE
             NEST = NEST+1
-            IF (NEST .EQ.6) THEN
+            IF (NEST .EQ. 3) THEN
                NST = 0
             END IF
          END IF
@@ -1238,6 +1184,11 @@ cF new starting vector for YS
              YS(I) = Y(I) + YS(I)
            END DO
 cF computation of the new value of ERRZ
+           IERR = 0
+           CALL FCN(N,XPH,YS,K1S,RPAR,IPAR)
+           NFCN=NFCN+1
+           NST = 0
+           NNST = 0
             ERRZ = 0.0d0
             IF (ITOL.EQ.0) THEN
              DO  I=1,N
@@ -1250,19 +1201,16 @@ cF computation of the new value of ERRZ
                ERRZ = ERRZ + (abs(Y(I)-YS(I))/SK)**2.0d0
              END DO
             END IF
+
             ERRZ = SQRT(ERRZ/N)
+
 cF initialization of the conditioning parameters
             ENORMZ1=ENORMVE
             KAPPA = ENORMVE
             GAMMA = 0d0
-            XTS = XPH
+            XST = XPH
             SIGMATOT = MAX(SIGMA,SIGMATOT)
-            if (IPRINT .GT. 0 ) THEN
-               WRITE(msg,*) 'RESTART'
-               CALL RPRINT(MSG)
-               WRITE(msg,*) 'SIGMATOT', SIGMATOT,'SIGMA',SIGMA,'XTS',XTS
-               CALL RPRINT(MSG)
-            END IF
+
          END IF
          IF (NRESTART .EQ. 0) SIGMATOT=SIGMA
 
@@ -1276,50 +1224,47 @@ C Karline: always print if nwarn1=0
 C              IF ( (IPRINT .GT. 0 .OR. NSTIFFCOND.EQ.1)
 C     &          .AND. (NWARN1 .EQ. 0) ) THEN
                IF (NWARN1 .EQ. 0) THEN
-                 WRITE(msg,*)
-     &            'THE PROBLEM SEEMS TO BECOME STIFF AT  X = ', X,
-     &            'SIGMA = ', SIGMATOT
-                 CALL RPRINT(MSG)
+        CALL Rprintd1(
+     &               'The problem seems to become stiff at x = ',X)
+        CALL Rprinti1('Sigma = ', SIGMATOT)
                  nwarn1 = 1
               END IF
                IDID=-6
+               IF (NSTIFFCOND .EQ. 2)  GOTO 760
             endif
             IF ( (NST .GT. MAXnst .OR. IaStiS .GT. MAXIaSti)
      &          .AND. (NWARN2 .EQ. 0) ) THEN
 
-              IF (IPRINT .GT. 0 .OR. NSTIFFCOND.EQ.1 ) THEN
-               WRITE(msg,*)'THE STEPSIZE IS RESTRICTED BY STABILITY
-     &    AT  X= ', X
-               CALL RPRINT(MSG)
-              END IF
+c              IF (IPRINT .GT. 0 .OR. NSTIFFCOND.EQ.1 ) THEN
+        CALL Rprintd1(
+     &'The stepsize is restricted only by stability reason at x = ', X)
+c              END IF
               nwarn2=1
               IDID=-7
+              IF (NSTIFFCOND .EQ. 2)  GOTO 760
             endif
 
             if ((nst .GT. MAXnst .AND. kappa/ENORMVE .GT. 1.01)
      &          .AND. (NWARN3 .EQ. 0) ) THEN
-               IF (IPRINT .GT. 0  .OR. NSTIFFCOND.EQ.1 ) THEN
-                WRITE(msg,*) 'THE STEPSIZE IS RESTRICTED ONLY BY
-     & STABILITY REASON AND  KAPPA > 1 AT X = ', X,
-     &  'KAPPA = ',KAPPA/ENORMVE
-                CALL RPRINT(MSG)
-               END IF
+c               IF (IPRINT .GT. 0  .OR. NSTIFFCOND.EQ.1 ) THEN
+        CALL Rprintd2('Kappa > 1; x = , kappa = ', X, KAPPA/ENORMVE)
+c               END IF
                NWARN3=1
                IDID=-8
+               IF (NSTIFFCOND .EQ. 2)  GOTO 760
              endif
-            if ( kappa/ENORMVE .GT. 1d20) THEN
-              IF (IPRINT .GT. 0 .OR. NSTIFFCOND.EQ.1 )  THEN
-                WRITE(msg,*) 'THE NUMERICAL SOLUTION IS UNSTABLE',
-     &   'KAPPA  = ', KAPPA
-                CALL RPRINT(MSG)
-               END IF
+            if ( kappa/ENORMVE .GT. 1d20 .AND. (NWARN4.EQ.0)) THEN
+c              IF (IPRINT .GT. 0 .OR. NSTIFFCOND.EQ.1 )  THEN
+        CALL Rprintd1(
+     &   'The numerical solution is unstable, kappa = ',KAPPA)
+c               END IF
                NWARN4  = 1
              IDID=-9
+             IF (NSTIFFCOND .EQ. 2)  GOTO 760
+
             endif
 
-           IF (NSTIFFCOND .EQ. 2) THEN
-              GOTO 760
-           END IF
+
         endif
 
       END IF
@@ -1339,6 +1284,13 @@ C ------- NORMAL EXIT
              kappa = kappa/ENORMVE
              gamma =gamma/ENORMVE
              sigmatot=max(sigma,sigmatot)
+             IF (IPRINT .GT. 0) THEN
+        CALL Rprintd1('Time     = ',X)
+        CALL Rprintd1('Kappa    = ',kappa/ENORMVE)
+        CALL Rprintd1('Gamma    = ',(gamma/ENORMVE)/(XPH-XST))
+        CALL Rprintd1('Sigma    = ',sigma)
+        CALL Rprintd1('Sigmatot = ',sigmatot)
+              END IF
             END IF
             IDID=1
             RETURN
@@ -1361,6 +1313,13 @@ C --- FAIL EXIT
             kappa = kappa/ENORMVE
             gamma =gamma/ENORMVE
             sigmatot=max(sigma,sigmatot)
+             IF (IPRINT .GT. 0) THEN
+        CALL Rprintd1('Time     = ',X)
+        CALL Rprintd1('Kappa    = ',kappa/ENORMVE)
+        CALL Rprintd1('Gamma    = ',(gamma/ENORMVE)/(XPH-XST))
+        CALL Rprintd1('Sigma    = ',sigma)
+        CALL Rprintd1('Sigmatot = ',sigmatot)
+         END IF
       END IF
       IDID=-4
       RETURN
@@ -1370,40 +1329,56 @@ C --- FAIL EXIT
             kappa = kappa/ENORMVE
             gamma =gamma/ENORMVE
             sigmatot=max(sigma,sigmatot)
+            IF (IPRINT .GT. 0) THEN
+        CALL Rprintd1('Time     = ',X)
+        CALL Rprintd1('Kappa    = ',kappa/ENORMVE)
+        CALL Rprintd1('Gamma    = ',(gamma/ENORMVE)/(XPH-XST))
+        CALL Rprintd1('Sigma    = ',sigma)
+        CALL Rprintd1('Sigmatot = ',sigmatot)
+         END IF
       END IF
-      IDID = -4
+
       RETURN
   77  CONTINUE
       IF (IPRINT.GT.0) THEN
-         WRITE(MSG,979)X
-         CALL RPRINT(MSG)
+      CALL Rprintd1('Exit of CashKarp at x = ',X)
       END IF
       IF (IPRINT.GT.0) THEN
-        WRITE(MSG,*)' STEP SIZE T0O SMALL, H=',H
-        CALL RPRINT(MSG)
+        CALL Rprintd1('Step size too small, h = ',H)
       END IF
       IDID=-3
       IF (NSTIFFCOND .GT.0 ) THEN
             kappa = kappa/ENORMVE
             gamma =gamma/ENORMVE
             sigmatot=max(sigma,sigmatot)
+          IF (IPRINT .GT. 0) THEN
+        CALL Rprintd1('Time     = ',X)
+        CALL Rprintd1('Kappa    = ',kappa/ENORMVE)
+        CALL Rprintd1('Gamma    = ',(gamma/ENORMVE)/(XPH-XST))
+        CALL Rprintd1('Sigma    = ',sigma)
+        CALL Rprintd1('Sigmatot = ',sigmatot)
+         END IF
       END IF
       RETURN
   78  CONTINUE
       IF (IPRINT.GT.0) THEN
-         WRITE(MSG,979)X
-         CALL RPRINT(MSG)
+      CALL Rprintd1('Exit of CashKarp at x = ',X)
       END IF
       IF (IPRINT.GT.0) THEN
-         WRITE(MSG,*)
-     &     ' MORE THAN NMAX =',NMAX,'STEPS ARE NEEDED'
-         CALL RPRINT(MSG)
+        CALL Rprinti1('More than nmax steps are needed: ',NMAX)
       END IF
       IDID=-2
       IF (NSTIFFCOND .GT.0 ) THEN
             kappa = kappa/ENORMVE
             gamma =gamma/ENORMVE
             sigmatot=max(sigma,sigmatot)
+            IF (IPRINT .GT. 0) THEN
+        CALL Rprintd1('Time     = ',X)
+        CALL Rprintd1('Kappa    = ',kappa/ENORMVE)
+        CALL Rprintd1('Gamma    = ',(gamma/ENORMVE)/(XPH-XST))
+        CALL Rprintd1('Sigma    = ',sigma)
+        CALL Rprintd1('Sigmatot = ',sigmatot)
+            END IF
       END IF
       RETURN
   79  CONTINUE
@@ -1412,12 +1387,17 @@ C --- FAIL EXIT
             kappa = kappa/ENORMVE
             gamma =gamma/ENORMVE
             sigmatot=max(sigma,sigmatot)
+            IF (IPRINT .GT. 0) THEN
+        CALL Rprintd1('Time     = ',X)
+        CALL Rprintd1('Kappa    = ',kappa/ENORMVE)
+        CALL Rprintd1('Gamma    = ',(gamma/ENORMVE)/(XPH-XST))
+        CALL Rprintd1('Sigma    = ',sigma)
+        CALL Rprintd1('Sigmatot = ',sigmatot)
+            END IF
       END IF
       IF (IPRINT.GT.0) THEN
-         WRITE(msg,979)X
-         CALL RPRINT(MSG)
+      CALL Rprintd1('Exit of CashKarp at x = ',X)
       END IF
- 979  FORMAT(' EXIT OF CASHKARP AT X=',E18.4)
       IDID=2
       RETURN
       END
@@ -1502,6 +1482,7 @@ C ----------------------------------------------------------
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       DIMENSION Y(N),Y1(N),F0(N),F1(N),ATOL(*),RTOL(*)
       DIMENSION RPAR(*),IPAR(*)
+
 C ---- COMPUTE A FIRST GUESS
 C ----   H = 0.01 * NORM (Y0) / NORM (F0)
       DNF=0.0D0
@@ -1555,8 +1536,8 @@ C ----  H**IORD * MAX ( NORM (F0), NORM (DER2)) = 0.01
          H1=(0.01D0/DER12)**(1.D0/IORD)
       END IF
 
-C --- THE STEPSIZE MUST BE GREATER THE 1.d-15
-      IF (H1 .GT. 1.D-15) THEN
+C --- THE STEPSIZE MUST BE GREATER THE 1.d-10
+      IF (H1 .GT. 1.D-10) THEN
          H=MIN(100*ABS(H),H1,HMAX)
       ELSE
          H=MIN(  100*ABS(H),ABS(HST),HMAX)
@@ -1564,12 +1545,16 @@ C --- THE STEPSIZE MUST BE GREATER THE 1.d-15
 
 
 C --- WE USE THE ERROR ESTIMATION TO COMPUTE ANOTHER STEPSIZE
-      FAC=ERR**EXPO1
-      FAC11 = FAC*10
-      H2=ABS(HST)/FAC11
+C      IF ERR .NE. NAN
+      IF ( .NOT. ERR .GT. 0.0d0) THEN
+        FAC=ERR**EXPO1
+        FAC11 = FAC*10
+        H2=ABS(HST)/FAC11
+
+C --- THE FINAL STEP IS THE MINIMUM IF H2 > 1e-10
+        IF (H2 .GT. 1e-10) H=MIN(H,H2,HMAX)
+      END IF
 
-C --- THE FINAL STEP IS THE MINIMUM
-      H=MIN(H,H2,HMAX)
       HINITCKSTIFF=SIGN(H,POSNEG)
       RETURN
       END
@@ -1592,7 +1577,6 @@ C ----------------------------------------------------------
       COMMON /CONCOEFF/ db31, db32,db33, db41,db42,db43,
      +                  db51,db52,db53, db61,db62,db63,
      +                  db71,db72,db73
-      CHARACTER (LEN=150) MSG
 
 C ----- COMPUTE PLACE OF II-TH COMPONENT
 c      db31 = 500.0d0/161.0d0
@@ -1616,8 +1600,7 @@ c      db73 = 5.0d0/2.0d0
       IF (ICOMP(J).EQ.II) I=J
    5  CONTINUE
       IF (I.EQ.0) THEN
-         WRITE (MSG,*) ' NO DENSE OUTPUT AVAILABLE FOR COMP.',II
-         CALL RPRINT(MSG)
+         CALL Rprinti1('No dense output available for comp. nr',II)
          RETURN
       END IF
 
@@ -1667,7 +1650,6 @@ C ----------------------------------------------------------
       COMMON /CONCOEFF/ db31, db32,db33, db41,db42,db43,
      +                  db51,db52,db53, db61,db62,db63,
      +                  db71,db72,db73
-      CHARACTER (LEN=150) MSG
 
       IF (hermite) THEN
         THETA=(X-XOLD)/H
